@@ -13,6 +13,7 @@ import multiprocessing
 import shutil
 from Bio import Phylo
 from tree2gd.seq import read_fasta_file
+import re
 
 def err_exit():
     sys.exit('\033[1;31;47m!!The Tree2gd program exited abnormally, please check the log file !!\033[0m')
@@ -33,7 +34,7 @@ def cmd_check(cmd):
 
 def main():
     pwd= os.getcwd()
-    parser = argparse.ArgumentParser(description='Tree2GD:A pipeline for WGD')
+    parser = argparse.ArgumentParser(description='Tree2GD:A pipeline for WGD V1.0.36')
     parser.add_argument('-i', type=str, required=True, metavar='input_dir',help='The CDS and pep dir.')
     parser.add_argument('-tree', type=str, required=True, metavar='phytree.nwk',help='The phytree file.')
     parser.add_argument('-t', type=int,metavar='t',default='1', help='Thread num.default:1')
@@ -121,40 +122,43 @@ def main():
 
     logging.info("Start checking required software..")
     if '1' in args.step:
-        diamond=cf.get("software", "diamond") if cf.has_option("software", "diamond") and cf.get("software", "diamond")!="" else os.sep.join([home_dir,"software", "diamond"])
-        seqkit=cf.get("software", "seqkit") if cf.has_option("software", "seqkit") and cf.get("software", "seqkit")!="" else os.sep.join([home_dir,"software", "seqkit"])
+        diamond=cf.get("software", "diamond") if cf.has_option("software", "diamond") and cf.get("software", "diamond")!="" else os.sep.join([home_dir,"tree2gd","software", "diamond"])
+        seqkit=cf.get("software", "seqkit") if cf.has_option("software", "seqkit") and cf.get("software", "seqkit")!="" else os.sep.join([home_dir,"tree2gd","software", "seqkit"])
         cmd_check([diamond,"help"])
         cmd_check(seqkit)
     if '2' in args.step:
-        phymcl=cf.get("software", "phymcl") if cf.has_option("software", "phymcl") and cf.get("software", "phymcl")!="" else os.sep.join([home_dir,"software", "PhyloMCL"])
+        phymcl=cf.get("software", "phymcl") if cf.has_option("software", "phymcl") and cf.get("software", "phymcl")!="" else os.sep.join([home_dir,"tree2gd","software", "PhyloMCL"])
         cmd_check(phymcl)
     if '3' in args.step:
-        dolloparsimony=cf.get("software", "dolloparsimony") if cf.has_option("software", "dolloparsimony") and cf.get("software", "dolloparsimony")!=""  else os.sep.join([home_dir,"software", "dolloparsimony"])
+        dolloparsimony=cf.get("software", "dolloparsimony") if cf.has_option("software", "dolloparsimony") and cf.get("software", "dolloparsimony")!=""  else os.sep.join([home_dir,"tree2gd","software", "dolloparsimony"])
         cmd_check(dolloparsimony)
     if '4' in args.step:
-        tree2gd=cf.get("software", "tree2gd") if cf.has_option("software", "tree2gd") and cf.get("software", "tree2gd")!="" else os.sep.join([home_dir,"software", "Tree2GD"])
+        tree2gd=cf.get("software", "tree2gd") if cf.has_option("software", "tree2gd") and cf.get("software", "tree2gd")!="" else os.sep.join([home_dir,"tree2gd","software", "Tree2GD"])
         cmd_check(tree2gd)
         cf.set("software", "tree2gd",tree2gd)
-        muscle=cf.get("software", "muscle") if cf.has_option("software", "muscle") and cf.get("software", "muscle")!="" else os.sep.join([home_dir,"software", "muscle"])
+        muscle=cf.get("software", "muscle") if cf.has_option("software", "muscle") and cf.get("software", "muscle")!="" else os.sep.join([home_dir,"tree2gd","software", "muscle"])
         cmd_check([muscle,"-version"])
         cf.set("software", "muscle",muscle)
-        iqtree=cf.get("software", "iqtree") if cf.has_option("software", "iqtree") and cf.get("software", "iqtree")!="" else os.sep.join([home_dir,"software", "iqtree"])
+        iqtree=cf.get("software", "iqtree") if cf.has_option("software", "iqtree") and cf.get("software", "iqtree")!="" else os.sep.join([home_dir,"tree2gd","software", "iqtree"])
         cmd_check([iqtree,"-h"])
         cf.set("software","iqtree",iqtree)
         if args.cds2tree:
-            Epal2nal=cf.get("software", "Epal2nal") if cf.has_option("software", "Epal2nal") and cf.get("software", "Epal2nal")!="" else os.sep.join([home_dir,"software", "Epal2nal.pl"])
+            Epal2nal=cf.get("software", "Epal2nal") if cf.has_option("software", "Epal2nal") and cf.get("software", "Epal2nal")!="" else os.sep.join([home_dir,"tree2gd","software", "Epal2nal.pl"])
             cmd_check(Epal2nal)
             cf.set("software","Epal2nal",Epal2nal)
     if '5' in args.step:
-        KaKs_Calculator=cf.get("software", "KaKs_Calculator") if cf.has_option("software", "KaKs_Calculator") and cf.get("software", "KaKs_Calculator")!="" else os.sep.join([home_dir,"software", "KaKs_Calculator"])
+        KaKs_Calculator=cf.get("software", "KaKs_Calculator") if cf.has_option("software", "KaKs_Calculator") and cf.get("software", "KaKs_Calculator")!="" else os.sep.join([home_dir,"tree2gd","software", "KaKs_Calculator"])
         cmd_check(KaKs_Calculator)
         cf.set("software", "KaKs_Calculator",KaKs_Calculator)
-        ParaAT=cf.get("software", "ParaAT") if cf.has_option("software", "ParaAT") and cf.get("software", "ParaAT")!="" else os.sep.join([home_dir,"software", "ParaAT.pl"])
-        cmd_check(ParaAT)
-        cf.set("software", "ParaAT",ParaAT)
-        ParaAT_aligncmd=cf.get("software", "ParaAT_aligncmd") if cf.has_option("software", "ParaAT_aligncmd") and cf.get("software", "ParaAT_aligncmd")!="" else os.sep.join([home_dir,"software", "muscle"])
-        cf.set("software", "ParaAT_aligncmd",ParaAT_aligncmd)
-        Epal2nal=cf.get("software", "Epal2nal") if cf.has_option("software", "Epal2nal") and cf.get("software", "Epal2nal")!="" else os.sep.join([home_dir,"software", "Epal2nal.pl"])
+        #ParaAT=cf.get("software", "ParaAT") if cf.has_option("software", "ParaAT") and cf.get("software", "ParaAT")!="" else os.sep.join([home_dir,"tree2gd","software", "ParaAT.pl"])
+        #cmd_check(ParaAT)
+        #cf.set("software", "ParaAT",ParaAT)
+        muscle=cf.get("software", "muscle") if cf.has_option("software", "muscle") and cf.get("software", "muscle")!="" else os.sep.join([home_dir,"tree2gd","software", "muscle"])
+        cmd_check([muscle,"-version"])
+        cf.set("software", "muscle",muscle)
+        #Kaks_aligncmd=cf.get("software", "Kaks_aligncmd") if cf.has_option("software", "Kaks_aligncmd") and cf.get("software", "Kaks_aligncmd")!="" else os.sep.join([home_dir,"tree2gd","software", "muscle"])
+        #cf.set("software", "Kaks_aligncmd",Kaks_aligncmd)
+        Epal2nal=cf.get("software", "Epal2nal") if cf.has_option("software", "Epal2nal") and cf.get("software", "Epal2nal")!="" else os.sep.join([home_dir,"tree2gd","software", "Epal2nal.pl"])
         cmd_check(Epal2nal)
         cf.set("software", "Epal2nal",Epal2nal)
 
@@ -193,6 +197,10 @@ def main():
         os.mkdir(step2out)
         if not cf.has_section('phymcl'):
             cf.add_section('phymcl')
+        with open(args.tree) as tree_in,open(os.sep.join([step2out,"phymcl.input.tree"]),"w") as out:
+            tree_text=tree_in.readlines()[0].strip('\n')
+            pattern = re.compile(r":\b[0-9]+(?:\.[0-9]+)?\b")
+            out.write(pattern.sub("",tree_text))
         from tree2gd.mcl import run_phymcl
         run_phymcl(step1out,phymcl,args,cf.items('phymcl'),step2out)
 
@@ -262,7 +270,7 @@ def main():
                     gene_pairs_idmap.append([l.strip().split("\t")[2],l.strip().split("\t")[3],l.strip().split("\t")[4],l.strip().split("\t")[5]])
         from tree2gd.kaks import run_kaks
         run_kaks(sp_list,step1out,args,cf,step4out,step5out,gene_pairs_idmap)
-        shutil.rmtree(os.sep.join([step5out,"all_gene_pairs_kaks"]))
+        #shutil.rmtree(os.sep.join([step5out,"all_gene_pairs_kaks"]))
 
     if '6' in args.step:
         step2out=os.sep.join([abs_out,'step2.MCL'])
@@ -284,7 +292,7 @@ def main():
         shutil.copyfile(os.sep.join([step4out,"Tree2GD_out","Phtree.nwk"]),os.sep.join([step6out,"Tree2GD_out","Phtree.nwk"]))
         shutil.copyfile(os.sep.join([step4out,"Tree2GD_out","summarytable.txt"]),os.sep.join([step6out,"Tree2GD_out","summarytable.txt"]))
         shutil.copytree(os.sep.join([step5out,"sp_kaks_out"]),os.sep.join([step6out,"sp_kaks_out"]))
-        shutil.copyfile(os.sep.join([home_dir,"software","Tree2GD_draw.R"]),os.sep.join([step6out,"Tree2GD_draw.R"]))
+        shutil.copyfile(os.sep.join([home_dir,"tree2gd","software","Tree2GD_draw.R"]),os.sep.join([step6out,"Tree2GD_draw.R"]))
         from tree2gd.plot import run_plot
         run_plot(step6out,args,cf)
         os.remove(os.sep.join([step6out,"Rplots.pdf"]))
@@ -294,9 +302,10 @@ def test():
     home_dir=os.path.dirname(os.path.abspath(__file__))
     parser = argparse.ArgumentParser(description='test cmd for Tree2GD')
     parser.add_argument('-t', type=int, default='1', help='Thread num.default:1')
-    parser.add_argument('--config',default=os.sep.join([home_dir,"example_data","config.ini"]),type=str, help='config.ini configuration file, leave it blank to run with default parameters and the program\'s own software version.')
+    parser.add_argument('--config',default=os.sep.join([home_dir,"tree2gd","example_data","config.ini"]),type=str, help='config.ini configuration file, leave it blank to run with default parameters and the program\'s own software version.')
     args = parser.parse_args()
-    subprocess.run("Tree2gd -i "+os.sep.join([home_dir,"example_data"])+" -tree "+os.sep.join([home_dir,"example_data","example.tree"])+" --config "+args.config+" -o ./Tree2gd_test_out -t "+str(args.t),shell=True)
+    subprocess.run("Tree2gd -i "+os.sep.join([home_dir,"tree2gd","example_data"])+" -tree "+os.sep.join([home_dir,"tree2gd","example_data","example.tree"])+" --config "+args.config+" -o ./Tree2gd_test_out -t "+str(args.t),shell=True)
+    shutil.copy(os.sep.join([home_dir,"tree2gd","example_data","full_config.ini"]),"./full_config.ini")
 
 if __name__ == '__main__':
     main()
